@@ -1,5 +1,5 @@
 import unittest
-import sphinx
+from sphinx.cmd import build
 import os.path
 
 import wsme.types
@@ -21,8 +21,8 @@ class TestSphinxExt(unittest.TestCase):
         if not os.path.exists('.test_sphinxext/'):
             os.makedirs('.test_sphinxext/')
         try:
-            sphinx.main([
-                '',
+            build.main([
+#                '',
                 '-b', 'html',
                 '-d', '.test_sphinxext/doctree',
                 docpath,
@@ -30,6 +30,7 @@ class TestSphinxExt(unittest.TestCase):
             ])
             assert Exception("Should raise SystemExit 0")
         except SystemExit as e:
+            print(e)
             assert e.code == 0
 
 
