@@ -1,6 +1,6 @@
 import weakref
 
-import pkg_resources
+import importlib_metadata
 
 from wsme.exc import ClientSideError
 
@@ -106,8 +106,9 @@ def register_protocol(protocol):
 def getprotocol(name, **options):
     protocol_class = registered_protocols.get(name)
     if protocol_class is None:
-        for entry_point in pkg_resources.iter_entry_points(
-                'wsme.protocols', name):
+        for entry_point in importlib_metadata.entry_points().select(
+            group='wsme.protocols',
+        ):
             if entry_point.name == name:
                 protocol_class = entry_point.load()
         if protocol_class is None:
