@@ -1,12 +1,9 @@
 # coding=utf-8
 
-import unittest
-import warnings
 import datetime
 import decimal
-import six
-
-from six import u, b
+import unittest
+import warnings
 
 from webtest import TestApp
 
@@ -17,7 +14,7 @@ import wsme.utils
 
 warnings.filterwarnings('ignore', module='webob.dec')
 
-binarysample = b('\x00\xff\x43')
+binarysample = b'\x00\xff\x43'
 
 try:
     1 / 0
@@ -88,11 +85,11 @@ class NestedOuterApi(object):
 class ReturnTypes(object):
     @expose(wsme.types.bytes)
     def getbytes(self):
-        return b("astring")
+        return b"astring"
 
     @expose(wsme.types.text)
     def gettext(self):
-        return u('\xe3\x81\xae')
+        return '\xe3\x81\xae'
 
     @expose(int)
     def getint(self):
@@ -137,7 +134,7 @@ class ReturnTypes(object):
 
     @expose([wsme.types.bytes])
     def getbytesarray(self):
-        return [b("A"), b("B"), b("C")]
+        return [b"A", b"B", b"C"]
 
     @expose([NestedOuter])
     def getnestedarray(self):
@@ -145,7 +142,7 @@ class ReturnTypes(object):
 
     @expose({wsme.types.bytes: NestedOuter})
     def getnesteddict(self):
-        return {b('a'): NestedOuter(), b('b'): NestedOuter()}
+        return {b'a': NestedOuter(), b'b': NestedOuter()}
 
     @expose(NestedOuter)
     def getobjectarrayattribute(self):
@@ -164,7 +161,7 @@ class ReturnTypes(object):
 
     @expose(myenumtype)
     def getenum(self):
-        return b('v2')
+        return b'v2'
 
     @expose(NamedAttrsObject)
     def getnamedattrsobj(self):
@@ -254,7 +251,7 @@ class ArgTypes(object):
     @validate(wsme.types.binary)
     def setbinary(self, value):
         print(repr(value))
-        self.assertEqual(type(value), six.binary_type)
+        self.assertEqual(type(value), bytes)
         return value
 
     @expose([wsme.types.bytes])
@@ -393,9 +390,9 @@ class ProtocolTestCase(unittest.TestCase):
     protocol_options = {}
 
     def assertTypedEquals(self, a, b, convert):
-        if isinstance(a, six.string_types):
+        if isinstance(a, str):
             a = convert(a)
-        if isinstance(b, six.string_types):
+        if isinstance(b, str):
             b = convert(b)
         self.assertEqual(a, b)
 
@@ -433,7 +430,7 @@ class ProtocolTestCase(unittest.TestCase):
         except CallException as e:
             self.assertEqual(e.faultcode, 'Client')
             self.assertEqual(e.faultstring.lower(),
-                             u('unknown function name: invalid_function'))
+                             'unknown function name: invalid_function')
 
     def test_serverside_error(self):
         try:
@@ -462,11 +459,11 @@ class ProtocolTestCase(unittest.TestCase):
 
     def test_return_bytes(self):
         r = self.call('returntypes/getbytes', _rt=wsme.types.bytes)
-        self.assertEqual(r, b('astring'))
+        self.assertEqual(r, b'astring')
 
     def test_return_text(self):
         r = self.call('returntypes/gettext', _rt=wsme.types.text)
-        self.assertEqual(r, u('\xe3\x81\xae'))
+        self.assertEqual(r, '\xe3\x81\xae')
 
     def test_return_int(self):
         r = self.call('returntypes/getint')
@@ -509,8 +506,8 @@ class ProtocolTestCase(unittest.TestCase):
         self.assertEqual(r, {'inner': {'aint': 0}})
 
     def test_return_bytesarray(self):
-        r = self.call('returntypes/getbytesarray', _rt=[six.binary_type])
-        self.assertEqual(r, [b('A'), b('B'), b('C')])
+        r = self.call('returntypes/getbytesarray', _rt=[bytes])
+        self.assertEqual(r, [b'A', b'B', b'C'])
 
     def test_return_nestedarray(self):
         r = self.call('returntypes/getnestedarray', _rt=[NestedOuter])
@@ -520,8 +517,8 @@ class ProtocolTestCase(unittest.TestCase):
         r = self.call('returntypes/getnesteddict',
                       _rt={wsme.types.bytes: NestedOuter})
         self.assertEqual(r, {
-            b('a'): {'inner': {'aint': 0}},
-            b('b'): {'inner': {'aint': 0}}
+            b'a': {'inner': {'aint': 0}},
+            b'b': {'inner': {'aint': 0}}
         })
 
     def test_return_objectarrayattribute(self):
@@ -543,23 +540,23 @@ class ProtocolTestCase(unittest.TestCase):
 
     def test_return_enum(self):
         r = self.call('returntypes/getenum', _rt=myenumtype)
-        self.assertEqual(r, b('v2'), r)
+        self.assertEqual(r, b'v2', r)
 
     def test_return_namedattrsobj(self):
         r = self.call('returntypes/getnamedattrsobj', _rt=NamedAttrsObject)
         self.assertEqual(r, {'attr.1': 5, 'attr.2': 6})
 
     def test_setbytes(self):
-        assert self.call('argtypes/setbytes', value=b('astring'),
-                         _rt=wsme.types.bytes) == b('astring')
+        assert self.call('argtypes/setbytes', value=b'astring',
+                         _rt=wsme.types.bytes) == b'astring'
 
     def test_settext(self):
-        assert self.call('argtypes/settext', value=u('\xe3\x81\xae'),
-                         _rt=wsme.types.text) == u('\xe3\x81\xae')
+        assert self.call('argtypes/settext', value='\xe3\x81\xae',
+                         _rt=wsme.types.text) == '\xe3\x81\xae'
 
     def test_settext_empty(self):
-        assert self.call('argtypes/settext', value=u(''),
-                         _rt=wsme.types.text) == u('')
+        assert self.call('argtypes/settext', value='',
+                         _rt=wsme.types.text) == ''
 
     def test_settext_none(self):
         self.assertEqual(
@@ -629,14 +626,14 @@ class ProtocolTestCase(unittest.TestCase):
         self.assertEqual(r, value)
 
     def test_setbytesarray(self):
-        value = [b("1"), b("2"), b("three")]
+        value = [b"1", b"2", b"three"]
         r = self.call('argtypes/setbytesarray',
                       value=(value, [wsme.types.bytes]),
                       _rt=[wsme.types.bytes])
         self.assertEqual(r, value)
 
     def test_settextarray(self):
-        value = [u("1")]
+        value = [u"1"]
         r = self.call('argtypes/settextarray',
                       value=(value, [wsme.types.text]),
                       _rt=[wsme.types.text])
@@ -664,17 +661,17 @@ class ProtocolTestCase(unittest.TestCase):
 
     def test_setnesteddict(self):
         value = {
-            b('o1'): {'inner': {'aint': 54}},
-            b('o2'): {'inner': {'aint': 55}},
+            b'o1': {'inner': {'aint': 54}},
+            b'o2': {'inner': {'aint': 55}},
         }
         r = self.call('argtypes/setnesteddict',
-                      value=(value, {six.binary_type: NestedOuter}),
-                      _rt={six.binary_type: NestedOuter})
+                      value=(value, {bytes: NestedOuter}),
+                      _rt={bytes: NestedOuter})
         print(r)
         self.assertEqual(r, value)
 
     def test_setenum(self):
-        value = b('v1')
+        value = b'v1'
         r = self.call('argtypes/setenum', value=value,
                       _rt=myenumtype)
         self.assertEqual(r, value)
@@ -697,7 +694,7 @@ class ProtocolTestCase(unittest.TestCase):
             assert "No error raised"
         except CallException as e:
             self.assertEqual(e.faultcode, 'Client')
-            self.assertEqual(e.faultstring, u('Missing argument: "value"'))
+            self.assertEqual(e.faultstring, 'Missing argument: "value"')
 
     def test_misc_multiply(self):
         self.assertEqual(self.call('misc/multiply', a=5, b=2, _rt=int), 10)
