@@ -72,7 +72,7 @@ def prepare_result(value, datatype):
         return value
     if datatype == wsme.types.bytes:
         return value.encode('ascii')
-    if type(value) != datatype:
+    if type(value) is not datatype:
         print(type(value), datatype)
         return datatype(value)
     return value
