@@ -45,7 +45,7 @@ def dumpxml(key, obj, datatype=None):
                 continue
             o = obj[name]
             el.append(dumpxml(name, o, attr.datatype))
-    elif type(obj) == dict:
+    elif type(obj) is dict:
         for name, value in obj.items():
             el.append(dumpxml(name, value))
     print(obj, datatype, et.tostring(el))
