@@ -2,10 +2,10 @@ import base64
 import datetime
 import decimal
 import inspect
+import io
 import logging
 import netaddr
 import re
-import six
 import sys
 import uuid
 import weakref
@@ -14,15 +14,15 @@ from wsme import exc
 
 log = logging.getLogger(__name__)
 
-#: The 'str' (python 2) or 'bytes' (python 3) type.
+#: Byte string.
 #: Its use should be restricted to
 #: pure ascii strings as the protocols will generally not be
 #: be able to send non-unicode strings.
 #: To transmit binary strings, use the :class:`binary` type
-bytes = six.binary_type
+bytes = bytes
 
 #: Unicode string.
-text = six.text_type
+text = str
 
 
 class ArrayType(object):
@@ -128,12 +128,12 @@ class BinaryType(UserType):
     def tobasetype(self, value):
         if value is None:
             return None
-        return base64.encodestring(value)
+        return base64.encodebytes(value)
 
     def frombasetype(self, value):
         if value is None:
             return None
-        return base64.decodestring(value)
+        return base64.decodebytes(value)
 
 
 #: The binary almost-native type
@@ -188,13 +188,13 @@ class StringType(UserType):
         Name = StringType(min_length=1, pattern='^[a-zA-Z ]*$')
 
     """
-    basetype = six.string_types
+    basetype = str
     name = "string"
 
     def __init__(self, min_length=None, max_length=None, pattern=None):
         self.min_length = min_length
         self.max_length = max_length
-        if isinstance(pattern, six.string_types):
+        if isinstance(pattern, str):
             self.pattern = re.compile(pattern)
         else:
             self.pattern = pattern
@@ -225,7 +225,7 @@ class IPv4AddressType(UserType):
     """
     A simple IPv4 type.
     """
-    basetype = six.string_types
+    basetype = str
     name = "ipv4address"
 
     @staticmethod
@@ -245,7 +245,7 @@ class IPv6AddressType(UserType):
 
     This type represents IPv6 addresses in the short format.
     """
-    basetype = six.string_types
+    basetype = str
     name = "ipv6address"
 
     @staticmethod
@@ -267,13 +267,13 @@ class UuidType(UserType):
     having dashes. For example, '6a0a707c-45ef-4758-b533-e55adddba8ce'
     and '6a0a707c45ef4758b533e55adddba8ce' are distinguished as valid.
     """
-    basetype = six.string_types
+    basetype = str
     name = "uuid"
 
     @staticmethod
     def validate(value):
         try:
-            return six.text_type((uuid.UUID(value)))
+            return str(uuid.UUID(value))
         except (TypeError, ValueError, AttributeError):
             error = 'Value should be UUID format'
             raise ValueError(error)
@@ -299,13 +299,13 @@ class Enum(UserType):
         self.values = set(values)
         name = kw.pop('name', None)
         if name is None:
-            name = "Enum(%s)" % ', '.join((six.text_type(v) for v in values))
+            name = "Enum(%s)" % ', '.join((str(v) for v in values))
         self.name = name
 
     def validate(self, value):
         if value not in self.values:
             raise ValueError("Value should be one of: %s" %
-                             ', '.join(map(six.text_type, self.values)))
+                             ', '.join(map(str, self.values)))
         return value
 
     def tobasetype(self, value):
@@ -335,13 +335,12 @@ Unset = UnsetType()
 HostRequest = object()
 
 
-pod_types = six.integer_types + (
-    bytes, text, float, bool)
+pod_types = (int, bytes, str, float, bool)
 dt_types = (datetime.date, datetime.time, datetime.datetime)
 extra_types = (binary, decimal.Decimal)
 native_types = pod_types + dt_types + extra_types
 # The types for which we allow promotion to certain numbers.
-_promotable_types = six.integer_types + (text, bytes)
+_promotable_types = (int, str, bytes)
 
 
 def iscomplex(datatype):
@@ -374,7 +373,7 @@ def validate_value(datatype, value):
     # Do type promotion/conversion and data validation for builtin
     # types.
     v_type = type(value)
-    if datatype in six.integer_types:
+    if datatype in (int,):
         if v_type in _promotable_types:
             try:
                 # Try to turn the value into an int
@@ -390,9 +389,9 @@ def validate_value(datatype, value):
             # An error is raised at the end of the function
             # when the types don't match.
             pass
-    elif datatype is text and isinstance(value, bytes):
+    elif datatype is str and isinstance(value, bytes):
         value = value.decode()
-    elif datatype is bytes and isinstance(value, text):
+    elif datatype is bytes and isinstance(value, str):
         value = value.encode()
 
     if not isinstance(value, datatype):
@@ -490,7 +489,7 @@ class wsattr(object):
         try:
             value = validate_value(self.datatype, value)
         except (ValueError, TypeError) as e:
-            raise exc.InvalidInput(self.name, value, six.text_type(e))
+            raise exc.InvalidInput(self.name, value, str(e))
         dataholder = self._get_dataholder(instance)
         if value is Unset:
             if hasattr(dataholder, self.key):
@@ -724,7 +723,7 @@ class Registry(object):
                 return ct
 
     def resolve_type(self, type_):
-        if isinstance(type_, six.string_types):
+        if isinstance(type_, str):
             return self.lookup(type_)
         if isinstance(type_, list):
             type_ = ArrayType(type_[0])
@@ -763,7 +762,7 @@ class BaseMeta(type):
             cls.__registry__.register(cls)
 
 
-class Base(six.with_metaclass(BaseMeta)):
+class Base(metaclass=BaseMeta):
     """Base type for complex types"""
     def __init__(self, **kw):
         for key, value in kw.items():
@@ -778,10 +777,10 @@ class File(Base):
     input, File can be loaded from a form file field.
     """
     #: The file name
-    filename = wsattr(text)
+    filename = wsattr(str)
 
     #: Mime type of the content
-    contenttype = wsattr(text)
+    contenttype = wsattr(str)
 
     def _get_content(self):
         if self._content is None and self._file:
@@ -806,14 +805,14 @@ class File(Base):
             if fieldstorage.file:
                 self._file = fieldstorage.file
                 self.filename = fieldstorage.filename
-                self.contenttype = text(fieldstorage.type)
+                self.contenttype = str(fieldstorage.type)
             else:
                 self._content = fieldstorage.value
 
     @property
     def file(self):
         if self._file is None and self._content:
-            self._file = six.BytesIO(self._content)
+            self._file = io.BytesIO(self._content)
         return self._file
 
 
