@@ -1,8 +1,9 @@
-import decimal
+import builtins
 import datetime
+import decimal
+from http import client as http_client
 import pytz
 import re
-from six.moves import builtins, http_client
 
 try:
     import dateutil.parser
