@@ -42,7 +42,7 @@ def signature(*args, **kw):
     sig = wsme.signature(*args, **kw)
 
     def decorator(f):
-        args = inspect.getargspec(f)[0]
+        args = inspect.getfullargspec(f)[0]
         ismethod = args and args[0] == 'self'
         sig(f)
         funcdef = wsme.api.FunctionDefinition.get(f)
