@@ -191,7 +191,7 @@ class TypeDocumenter(autodoc.ClassDocumenter):
 
     option_spec = dict(
         autodoc.ClassDocumenter.option_spec,
-        **{'protocols': lambda l: [v.strip() for v in l.split(',')],
+        **{'protocols': lambda line: [v.strip() for v in line.split(',')],
            'samples-slot': check_samples_slot,
            })
 
@@ -223,13 +223,12 @@ class TypeDocumenter(autodoc.ClassDocumenter):
         else:
             return False
 
-    def add_content(self, more_content, no_docstring=False):
+    def add_content(self, more_content):
         # Check where to include the samples
         samples_slot = self.options.samples_slot or self.default_samples_slot
 
         def add_docstring():
-            super(TypeDocumenter, self).add_content(
-                more_content, no_docstring)
+            super(TypeDocumenter, self).add_content(more_content)
 
         def add_samples():
             protocols = get_protocols(
@@ -284,14 +283,13 @@ class AttributeDocumenter(autodoc.AttributeDocumenter):
             self.datatype = self.object.datatype
         return success
 
-    def add_content(self, more_content, no_docstring=False):
+    def add_content(self, more_content):
         self.add_line(
             u':type: %s' % datatypename(self.datatype),
             '<wsmeext.sphinxext>'
         )
         self.add_line(u'', '<wsmeext.sphinxext>')
-        super(AttributeDocumenter, self).add_content(
-            more_content, no_docstring)
+        super(AttributeDocumenter, self).add_content(more_content)
 
     def add_directive_header(self, sig):
         super(AttributeDocumenter, self).add_directive_header(sig)
@@ -376,7 +374,7 @@ class FunctionDirective(PyMethod):
     objtype = 'function'
 
     def get_signature_prefix(self, sig):
-        return 'function '
+        return []
 
 
 def document_function(funcdef, docstrings=None, protocols=['restjson']):
@@ -528,8 +526,8 @@ class FunctionDocumenter(autodoc.MethodDocumenter):
             self.wsme_fd, docstrings, protocols
         )
 
-    def add_content(self, more_content, no_docstring=False):
-        super(FunctionDocumenter, self).add_content(more_content, no_docstring)
+    def add_content(self, more_content):
+        super(FunctionDocumenter, self).add_content(more_content)
 
     def format_name(self):
         return self.wsme_fd.name
